@@ -1,11 +1,14 @@
 import importlib.util
 import os
-from inspect import isclass
+from inspect import getfullargspec, getsource, isclass
+from typing import Dict, List
 
 import holidays
 import numpy as np
 import pandas as pd
 from pandas.tseries.frequencies import to_offset
+from woodwork import list_logical_types, list_semantic_tags
+from woodwork.column_schema import ColumnSchema
 
 import featuretools
 from featuretools.primitives.base import (
@@ -41,6 +44,7 @@ def get_transform_primitives():
 
 
 def list_primitives():
+    """Returns a DataFrame that lists and describes each built-in primitive."""
     trans_names, trans_primitives, valid_inputs, return_type = _get_names_primitives(
         get_transform_primitives
     )
@@ -93,6 +97,51 @@ def list_primitives():
     return pd.concat([agg_df, transform_df], ignore_index=True)[columns]
 
 
+def summarize_primitives() -> pd.DataFrame:
+    """Returns a metrics summary DataFrame of all primitives found in list_primitives."""
+    (
+        trans_names,
+        trans_primitives,
+        trans_valid_inputs,
+        trans_return_type,
+    ) = _get_names_primitives(get_transform_primitives)
+
+    (
+        agg_names,
+        agg_primitives,
+        agg_valid_inputs,
+        agg_return_type,
+    ) = _get_names_primitives(get_aggregation_primitives)
+
+    tot_trans = len(trans_names)
+    tot_agg = len(agg_names)
+    tot_prims = tot_trans + tot_agg
+    all_primitives = trans_primitives + agg_primitives
+    primitives_summary = _get_summary_primitives(all_primitives)
+    summary_dict = {
+        "total_primitives": tot_prims,
+        "aggregation_primitives": tot_agg,
+        "transform_primitives": tot_trans,
+        **primitives_summary["general_metrics"],
+    }
+    summary_dict.update(
+        {
+            f"uses_{ltype}_input": count
+            for ltype, count in primitives_summary["logical_type_input_metrics"].items()
+        }
+    )
+    summary_dict.update(
+        {
+            f"uses_{tag}_tag_input": count
+            for tag, count in primitives_summary["semantic_tag_metrics"].items()
+        }
+    )
+    summary_df = pd.DataFrame(
+        [{"Metric": k, "Count": v} for k, v in summary_dict.items()]
+    )
+    return summary_df
+
+
 def get_default_aggregation_primitives():
     agg_primitives = [
         featuretools.primitives.Sum,
@@ -134,6 +183,84 @@ def _get_descriptions(primitives):
     return descriptions
 
 
+def _get_summary_primitives(primitives: List) -> Dict[str, int]:
+    """Provides metrics for a list of primitives."""
+    unique_input_types = set()
+    unique_output_types = set()
+    uses_multi_input = 0
+    uses_multi_output = 0
+    uses_external_data = 0
+    are_controllable = 0
+    logical_type_metrics = {
+        log_type: 0 for log_type in list(list_logical_types()["type_string"])
+    }
+    semantic_tag_metrics = {
+        sem_tag: 0 for sem_tag in list(list_semantic_tags()["name"])
+    }
+    semantic_tag_metrics.update(
+        {"foreign_key": 0}
+    )  # not currently in list_semantic_tags()
+
+    for prim in primitives:
+        log_in_type_checks = set()
+        sem_tag_type_checks = set()
+        input_types = prim.flatten_nested_input_types(prim.input_types)
+        _check_input_types(
+            input_types, log_in_type_checks, sem_tag_type_checks, unique_input_types
+        )
+        for ltype in list(log_in_type_checks):
+            logical_type_metrics[ltype] += 1
+
+        for sem_tag in list(sem_tag_type_checks):
+            semantic_tag_metrics[sem_tag] += 1
+
+        if len(prim.input_types) > 1:
+            uses_multi_input += 1
+
+        # checks if number_output_features is set as an instance variable or set as a constant
+        if (
+            "self.number_output_features =" in getsource(prim.__init__)
+            or prim.number_output_features > 1
+        ):
+            uses_multi_output += 1
+        unique_output_types.add(str(prim.return_type))
+
+        if hasattr(prim, "filename"):
+            uses_external_data += 1
+
+        if len(getfullargspec(prim.__init__).args) > 1:
+            are_controllable += 1
+
+    return {
+        "general_metrics": {
+            "unique_input_types": len(unique_input_types),
+            "unique_output_types": len(unique_output_types),
+            "uses_multi_input": uses_multi_input,
+            "uses_multi_output": uses_multi_output,
+            "uses_external_data": uses_external_data,
+            "are_controllable": are_controllable,
+        },
+        "logical_type_input_metrics": logical_type_metrics,
+        "semantic_tag_metrics": semantic_tag_metrics,
+    }
+
+
+def _check_input_types(
+    input_types: List[ColumnSchema],
+    log_in_type_checks: set,
+    sem_tag_type_checks: set,
+    unique_input_types: set,
+):
+    """Checks if any logical types or semantic tags occur in a list of Woodwork input types and keeps track of unique input types."""
+    for in_type in input_types:
+        if in_type.semantic_tags:
+            for sem_tag in in_type.semantic_tags:
+                sem_tag_type_checks.add(sem_tag)
+        if in_type.logical_type:
+            log_in_type_checks.add(in_type.logical_type.type_string)
+        unique_input_types.add(str(in_type))
+
+
 def _get_names_primitives(primitive_func):
     names = []
     primitives = []
@@ -144,7 +271,9 @@ def _get_names_primitives(primitive_func):
         primitives.append(primitive)
         input_types = _get_unique_input_types(primitive.input_types)
         valid_inputs.append(", ".join(input_types))
-        return_type.append(getattr(primitive.return_type, "__name__", None))
+        return_type.append(
+            str(primitive.return_type)
+        ) if primitive.return_type is not None else return_type.append(None)
     return names, primitives, valid_inputs, return_type
 
 
