@@ -27,18 +27,28 @@ from featuretools.primitives import (
     ScalarSubtractNumericFeature,
     SubtractNumeric,
     SubtractNumericScalar,
-    Sum
+    Sum,
 )
 from featuretools.tests.testing_utils import to_pandas
 
 
 def test_overrides(es):
-    value = ft.Feature(es['log'].ww['value'])
-    value2 = ft.Feature(es['log'].ww['value_2'])
+    value = ft.Feature(es["log"].ww["value"])
+    value2 = ft.Feature(es["log"].ww["value_2"])
 
-    feats = [AddNumeric, SubtractNumeric, MultiplyNumeric, DivideNumeric,
-             ModuloNumeric, GreaterThan, LessThan, Equal, NotEqual,
-             GreaterThanEqualTo, LessThanEqualTo]
+    feats = [
+        AddNumeric,
+        SubtractNumeric,
+        MultiplyNumeric,
+        DivideNumeric,
+        ModuloNumeric,
+        GreaterThan,
+        LessThan,
+        Equal,
+        NotEqual,
+        GreaterThanEqualTo,
+        LessThanEqualTo,
+    ]
     assert ft.Feature(value, primitive=Negate).unique_name() == (-value).unique_name()
 
     compares = [(value, value), (value, value2)]
@@ -54,7 +64,6 @@ def test_overrides(es):
         value != value,
         value >= value,
         value <= value,
-
         value + value2,
         value - value2,
         value * value2,
@@ -76,34 +85,43 @@ def test_overrides(es):
 
 
 def test_override_boolean(es):
-    count = ft.Feature(es['log'].ww['id'], parent_dataframe_name='sessions', primitive=Count)
+    count = ft.Feature(
+        es["log"].ww["id"], parent_dataframe_name="sessions", primitive=Count
+    )
     count_lo = ft.Feature(count, primitive=GreaterThanScalar(1))
     count_hi = ft.Feature(count, primitive=LessThanScalar(10))
 
-    to_test = [[True, True, True],
-               [True, True, False],
-               [False, False, True]]
+    to_test = [[True, True, True], [True, True, False], [False, False, True]]
 
     features = []
     features.append(count_lo.OR(count_hi))
     features.append(count_lo.AND(count_hi))
     features.append(~(count_lo.AND(count_hi)))
 
-    df = ft.calculate_feature_matrix(entityset=es, features=features, instance_ids=[0, 1, 2])
-    df = to_pandas(df, index='id', sort_index=True)
+    df = ft.calculate_feature_matrix(
+        entityset=es, features=features, instance_ids=[0, 1, 2]
+    )
+    df = to_pandas(df, index="id", sort_index=True)
     for i, test in enumerate(to_test):
         v = df[features[i].get_name()].tolist()
         assert v == test
 
 
 def test_scalar_overrides(es):
-    value = ft.Feature(es['log'].ww['value'])
+    value = ft.Feature(es["log"].ww["value"])
 
     feats = [
-        AddNumericScalar, SubtractNumericScalar, MultiplyNumericScalar,
-        DivideNumericScalar, ModuloNumericScalar, GreaterThanScalar,
-        LessThanScalar, EqualScalar, NotEqualScalar, GreaterThanEqualToScalar,
-        LessThanEqualToScalar
+        AddNumericScalar,
+        SubtractNumericScalar,
+        MultiplyNumericScalar,
+        DivideNumericScalar,
+        ModuloNumericScalar,
+        GreaterThanScalar,
+        LessThanScalar,
+        EqualScalar,
+        NotEqualScalar,
+        GreaterThanEqualToScalar,
+        LessThanEqualToScalar,
     ]
 
     overrides = [
@@ -125,13 +143,20 @@ def test_scalar_overrides(es):
         o = overrides.pop(0)
         assert o.unique_name() == f.unique_name()
 
-    value2 = ft.Feature(es['log'].ww['value_2'])
+    value2 = ft.Feature(es["log"].ww["value_2"])
 
     reverse_feats = [
-        AddNumericScalar, ScalarSubtractNumericFeature, MultiplyNumericScalar,
-        DivideByFeature, ModuloByFeature, GreaterThanScalar, LessThanScalar,
-        EqualScalar, NotEqualScalar, GreaterThanEqualToScalar,
-        LessThanEqualToScalar
+        AddNumericScalar,
+        ScalarSubtractNumericFeature,
+        MultiplyNumericScalar,
+        DivideByFeature,
+        ModuloByFeature,
+        GreaterThanScalar,
+        LessThanScalar,
+        EqualScalar,
+        NotEqualScalar,
+        GreaterThanEqualToScalar,
+        LessThanEqualToScalar,
     ]
     reverse_overrides = [
         2 + value2,
@@ -144,7 +169,7 @@ def test_scalar_overrides(es):
         2 == value2,
         2 != value2,
         2 <= value2,
-        2 >= value2
+        2 >= value2,
     ]
     for feat in reverse_feats:
         f = ft.Feature(value2, primitive=feat(2))
@@ -153,23 +178,31 @@ def test_scalar_overrides(es):
 
 
 def test_override_cmp_from_column(es):
-    count_lo = ft.Feature(es['log'].ww['value']) > 1
+    count_lo = ft.Feature(es["log"].ww["value"]) > 1
 
     to_test = [False, True, True]
 
     features = [count_lo]
 
-    df = to_pandas(ft.calculate_feature_matrix(entityset=es, features=features, instance_ids=[0, 1, 2]),
-                   index='id',
-                   sort_index=True)
+    df = to_pandas(
+        ft.calculate_feature_matrix(
+            entityset=es, features=features, instance_ids=[0, 1, 2]
+        ),
+        index="id",
+        sort_index=True,
+    )
     v = df[count_lo.get_name()].tolist()
     for i, test in enumerate(to_test):
         assert v[i] == test
 
 
 def test_override_cmp(es):
-    count = ft.Feature(es['log'].ww['id'], parent_dataframe_name='sessions', primitive=Count)
-    _sum = ft.Feature(es['log'].ww['value'], parent_dataframe_name='sessions', primitive=Sum)
+    count = ft.Feature(
+        es["log"].ww["id"], parent_dataframe_name="sessions", primitive=Count
+    )
+    _sum = ft.Feature(
+        es["log"].ww["value"], parent_dataframe_name="sessions", primitive=Sum
+    )
     gt_lo = count > 1
     gt_other = count > _sum
     ge_lo = count >= 1
@@ -181,19 +214,33 @@ def test_override_cmp(es):
     ne_lo = count != 1
     ne_other = count != _sum
 
-    to_test = [[True, True, False],
-               [False, False, True],
-               [True, True, True],
-               [False, False, True],
-               [True, True, True],
-               [True, True, False],
-               [True, True, True],
-               [True, True, False]]
-    features = [gt_lo, gt_other, ge_lo, ge_other, lt_hi,
-                lt_other, le_hi, le_other, ne_lo, ne_other]
+    to_test = [
+        [True, True, False],
+        [False, False, True],
+        [True, True, True],
+        [False, False, True],
+        [True, True, True],
+        [True, True, False],
+        [True, True, True],
+        [True, True, False],
+    ]
+    features = [
+        gt_lo,
+        gt_other,
+        ge_lo,
+        ge_other,
+        lt_hi,
+        lt_other,
+        le_hi,
+        le_other,
+        ne_lo,
+        ne_other,
+    ]
 
-    df = ft.calculate_feature_matrix(entityset=es, features=features, instance_ids=[0, 1, 2])
-    df = to_pandas(df, index='id', sort_index=True)
+    df = ft.calculate_feature_matrix(
+        entityset=es, features=features, instance_ids=[0, 1, 2]
+    )
+    df = to_pandas(df, index="id", sort_index=True)
     for i, test in enumerate(to_test):
         v = df[features[i].get_name()].tolist()
         assert v == test
